Welcome to ycleptic's documentation!
====================================

**Ycleptic** (e-klep-tic) is a Python tool for facilitating the definition of
YAML-format input files.  It allows for specification of default values and 
value choices.  It allows for fully nested dictionary/list structures for
detailed input file organization.

.. note::

   Ycleptic is under active development.

Contents
--------

.. toctree::

   installation
   usage

